Learn R Programming

nlts (version 0.1-9)

contingency.periodogram: The contingency periodogram for periodicity in categorical time series

Description

A funcion to estimate the contingency periodogram to test for periodicity in categorical time series.

Usage

contingency.periodogram(x, maxper = 6)

Arguments

Value

An object of class "contingency.periodogram" is returned consisting of a matrix with a row for each period considered. The columns are:exact.pthe fischer exact test at each lag.chi-valthe asymptotic chi-square value.dfthe chi-square degrees-of-freedom.asympt.pthe chi-squared asymptotic p-value.

Details

This is the contingency periodogram of Pierre Legedre and Pierre Dutielle to test for periodicity in categorical time series. I have coded the function so as to provide both the Fisher exact test and the asymptotic chi-square test.

References

Legendre et al. (1981) The contingency periodogram: A method for identifying rhytms in series of nonmetric ecological data. Journal of Ecology, 69, 965-979.

See Also

plot.contingency.periodogram

Examples

Run this code
data(plodia)
    data<-as.factor((scale(plodia) > 0))
    fit <- contingency.periodogram(data, maxper = 9) 
    plot.contingency.periodogram(fit)

Run the code above in your browser using DataLab