Learn R Programming

nlts (version 0.1-9)

lin.order.cls: The order of a time series using cross-validation of the linear autoregressive model (conditional least-squares).

Description

A function to estimate the order of a time series using cross-validation of the linear autoregressive model. Coefficients are estimated using conditional least-squares.

Usage

lin.order.cls(x, order=1:5, n.cond = 5, echo = TRUE)

Arguments

Value

An object of class "lin.order" is returned consisting of the following components:orderthe grid of orders considered.CVdthe cross-validation errors across the grid of orders.

Details

The time series is normalized prior to cross-validation. Note that if the dynamics is highly nonlinear, the nonparametric order-estimators (ll.order) may be more appropriate. (I coded this function to use for comparison with the nonparametric methods, because these also uses (nonlinear) conditional least-squares.)

See Also

summary.lin.order plot.lin.order ll.order

Examples

Run this code
data(plodia)
    fit <- lin.order.cls(sqrt(plodia), order=1:5)
    plot.lin.order(fit)
    summary.lin.order(fit)

Run the code above in your browser using DataLab