Learn R Programming

nlts (version 0.1-9)

specar.ci: Confidence interval for the ar-spectrum and the dominant period.

Description

A funcion to estimate a "confidence interval" for the power spectrum and in particular a confidence interval for the dominant period. The function uses resampling of the autoregressive parameters to attain the estimate.

Usage

specar.ci(x, order, resamp = 500, nfreq = 100, echo = TRUE)

Arguments

Value

An object of class "specar.ci" is returned consisting of the following components:orderthe ar-order.spectrum$freqthe spectral frequencies.spectrum$specthe estimated power-spectrum of the data.resamp$spectrumgives the quantile summary for the resampling distribution of the spectral powers.resamp$maxfreqthe full vector of output for the resampled max.frequencies.

Details

A "confidence interval" for the periodogram is obtained by resampling the ar-coefficients using the variance-covariance matrix from the ar.mle object. If a zero'th order process is chosen by using the AIC criterion, a first order process will be used. If the dynamics is highly nonlinear, the parametric estimate of the power spectrum may be inappropriate.

See Also

plot.specar.ci summary.specar.ci

Examples

Run this code
data(plodia)


    fit <- specar.ci(sqrt(plodia), order=3, resamp=10) 

    plot.specar.ci(fit, period=FALSE)

    summary.specar.ci(fit)

Run the code above in your browser using DataLab