`summary' method for objects of class "specar.ci".
# S3 method for specar.ci
summary(object, period = TRUE, ...)an object of class "specar.ci", usually, as a result of a call
to specar.ci.
If TRUE the summary is given in terms of the period, if false it is in terms of the frequency
generic plot arguments.
A list summarizing the analysis is printed:
the dominant period.
the p.value.