lin.order.cls: The order of a time series using cross-validation
of the linear autoregressive model
(conditional least-squares).
Description
A function to estimate the order of a time series
using cross-validation of the linear autoregressive
model. Coefficients are estimated using conditional
least-squares.
An object of class "lin.order" is returned
consisting of the following components:orderthe grid of orders considered.CVdthe cross-validation errors across the
grid of orders.
Details
The time series is normalized prior to cross-validation.
Note that if the dynamics is highly nonlinear, the nonparametric
order-estimators (ll.order) may be more appropriate.
(I coded this
function to use for comparison with the nonparametric methods,
because these also uses (nonlinear) conditional least-squares.)