portman.Q: Ljung-Box test for whiteness in a time series.
Description
portman.Q uses the cummulative ACF to test for whiteness of a time series.
Usage
portman.Q(x, K)
Arguments
x
A time series (vector without missing values).
K
the maximum lag of the ACF to be used in the test.
Value
A vector is returned consisting of the asymtpotic chi-square value,
the associated d.f. and asymptotic p.val for the test of whiteness.
Details
This is the Ljung-Box version of the the Portemanteau test for whiteness
(Tong 1990). It may in particular be usefull to test for whiteness in the
residuals from time series models.
References
Tong, H. (1990) Non-linear time series : a dynamical system
approach. Clarendon Press, Oxford.