Learn R Programming

nlts (version 0.2-0)

portman.Q: The Ljung-Box test for whiteness in a time series.

Description

portman.Q uses the cummulative ACF to test for whiteness of a time series.

Usage

portman.Q(x, K)

Arguments

x

A time series (vector without missing values).

K

the maximum lag of the ACF to be used in the test.

Value

A vector is returned consisting of the asymtpotic chi-square value, the associated d.f. and asymptotic p.val for the test of whiteness.

Details

This is the Ljung-Box version of the the Portemanteau test for whiteness (Tong 1990). It may in particular be usefull to test for whiteness in the residuals from time series models.

References

Tong, H. (1990) Non-linear time series : a dynamical system approach. Clarendon Press, Oxford.

Examples

Run this code
# NOT RUN {
   data(plodia)

   portman.Q(sqrt(plodia), K = 10) 

   fit <- ar(sqrt(plodia)) 
   portman.Q(na.omit(fit$resid), K = 10) 
# }

Run the code above in your browser using DataLab