prediction.profile.ll: Nonlinear forecasting at verying lags using local polynomial regression.
Description
A wrapper function around ll.order to calculate prediction profiles
(a la Sugihara \& May 1990 and Yao \& Tong 1994). The method uses leave-one-out
cross-validation of the local regression (with CV optimized bandwidth)
against lagged-abundances at various lags.
Usage
prediction.profile.ll(x, step = 1:10, order = 1:5, deg = 2,
bandwidth = c(seq(0.3, 1.5, by = 0.1), 2:10))
Arguments
x
A time series without missing values.
step
The vector of time steps for predicition.
order
The candidate orders. The default is 1:5.
deg
The degree of the local polynomial.
bandwidth
The candidate bandwidths to be considered.
Value
An object of class "ppll" consisting of a list
with the following components:
Sugihara, G., and May, R.M. (1990) Nonlinear forecasting
as a way of distinguishing chaos from measurement error
in time series. Nature 344, 734-741
Yao, Q. and Tong, H. (1994) Quantifying the influence
of initial values on non-linear prediction.
Journal of Royal Statistical Society B, 56, 701-725.
Fan, J., Yao, Q., and Tong, H. (1996) Estimation of
conditional densities and sensitivity measures
in nonlinear dynamical systems. Biometrika, 83, 189-206.
# NOT RUN { data(plodia)
fit1 <- prediction.profile.ll(sqrt(plodia), step=1:3, order=1:3,
bandwidth = seq(0.5, 1.5, by = 0.5))
# }# NOT RUN {plot.ppll(fit1)
# }