Learn R Programming

nlts (version 0.2-0)

summary.specar.ci: Summarizes ar-spectra with CI's

Description

`summary' method for class "specar.ci".

Usage

# S3 method for specar.ci
summary(object, period=TRUE, …)

Arguments

object

an object of class "specar.ci", usually, as a result of a call to specar.ci.

period

If TRUE the summary is given in terms of the period, if false it is in terms of the frequency

no other arguments currently allowed

Value

A list summarizing the analysis is printed:

period

the dominant period.

p.val

the p.value.

See Also

specar.ci